Alpine.js helper functions for Hiccup templates.
Provides declarative attributes for common Alpine patterns while maintaining compatibility with HTMX server communication.
Alpine.js handles client-side reactivity (dropdowns, state, transitions) while HTMX handles server communication. Alpine's MutationObserver automatically detects HTMX DOM changes, eliminating manual re-initialization.
Key patterns:
Alpine.js helper functions for Hiccup templates. Provides declarative attributes for common Alpine patterns while maintaining compatibility with HTMX server communication. Alpine.js handles client-side reactivity (dropdowns, state, transitions) while HTMX handles server communication. Alpine's MutationObserver automatically detects HTMX DOM changes, eliminating manual re-initialization. Key patterns: - x-data: Component state initialization - x-bind: Dynamic attribute binding - x-on/@: Event handlers - x-show: Conditional visibility with transitions - x-model: Two-way data binding - $persist: LocalStorage persistence - $store: Global reactive stores
Pure UI component functions for HTML generation using Hiccup.
These are reusable, generic components that can be used across all domain modules. No domain-specific logic should be placed here - only pure presentation functions.
Pure UI component functions for HTML generation using Hiccup. These are reusable, generic components that can be used across all domain modules. No domain-specific logic should be placed here - only pure presentation functions.
Lucide-based icon system for Boundary Framework.
Provides inline SVG icons that work seamlessly with Hiccup. Icons are ISC-licensed from https://lucide.dev/
Usage: (icon :home) (icon :users {:size 20 :class "text-primary"}) (icon :chevron-right {:stroke-width 2.5})
Available icons can be listed with (available-icons)
Lucide-based icon system for Boundary Framework.
Provides inline SVG icons that work seamlessly with Hiccup.
Icons are ISC-licensed from https://lucide.dev/
Usage:
(icon :home)
(icon :users {:size 20 :class "text-primary"})
(icon :chevron-right {:stroke-width 2.5})
Available icons can be listed with (available-icons)Layout components for consistent page structure.
Contains page layout, navigation, and structural components that provide consistent look and feel across all domain modules.
Layout components for consistent page structure. Contains page layout, navigation, and structural components that provide consistent look and feel across all domain modules.
Shared table UI helpers (sorting, paging) for Hiccup-based web UIs.
Shared table UI helpers (sorting, paging) for Hiccup-based web UIs.
Validation error transformation utilities for UI display.
Provides functions to convert Malli validation errors into formats suitable for inline field error display in web forms.
Validation error transformation utilities for UI display. Provides functions to convert Malli validation errors into formats suitable for inline field error display in web forms.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |